@@ -65,6 +65,12 @@ ignore_set = {"meta"}  # At this moment, it's ignored
 # Sections that define types
 types_set = {ptype_key, rtype_key, vartype_key}  # Sections that define types
 
+# Standard section keys:
+# - Complies with (https://sphinx-rtd-tutorial.readthedocs.io/en/latest/docstrings.html#the-sphinx-docstring-format)
+standard_param_key = "param"
+standard_return_key = "return"
+standard_raise_key = "raises"
+
 # ============================================================================
 # Regular expressions for parsing docstrings:
 # ============================================================================
@@ -214,6 +220,17 @@ class Violations:
     DOC010 = (True, "DOC010", "Section definition contains invalid whitespace ({!r})")
     DOC011 = (True, "DOC011", "Trailing non-empty lines after last section")
     DOC012 = (True, "DOC012", "Leading whitespaces in first non-blank line ({!r})")
+
+    # **DOC013** recommends using the [standard sections keys]
+    # (https://sphinx-rtd-tutorial.readthedocs.io/en/latest/docstrings.html#the-sphinx-docstring-format)
+    # instead of all the
+    # variants [accepted by Sphinx](https://www.sphinx-doc.org/en/master/usage/domains/python.html#info-field-lists),
+    # in order to improve consistency and clarity in parameter documentation within docstrings.
+    DOC013 = (False, "DOC013", "Use the common section key ({!r}) instead of ({!r})")  # Disabled by default
+
+    # PEP257 recommends that the summary line should fit on a single line, followed by a blank line,
+    # followed by a more elaborate description
+    DOC014 = (False, "DOC014", "Summary must fit on a single line and is separated from the rest by a blank line.")
     # ----------------------------------------------------------------------------
     # DOC1xx: Parameter issues
     # ----------------------------------------------------------------------------
@@ -336,6 +353,11 @@ class Violations:
                 if line and not line.endswith('.'):
                     yield cls.DOC008, ()  # Summary should end with a period
 
+            # Take first non-blank lines in summary
+            first_summary_lines = sum(1 for _ in itertools.takewhile(bool, summary_lines))
+            if first_summary_lines > 1:
+                yield cls.DOC014, ()  # Summary must fit on a single line
+
     @classmethod
     def validate_params(cls, parsed_docs, parsed_params, /):
         """
@@ -379,6 +401,10 @@ class Violations:
                 # Params after returns are considered misplaced
                 yield cls.DOC007, (section_key, first_return.section_key,)
 
+            if section_key in param_set and section_key != standard_param_key:
+                # Suggest using standard section key
+                yield cls.DOC013, (standard_param_key, section_key)
+
             if name and name not in documented:
                 documented.append(name)
 
@@ -439,6 +465,10 @@ class Violations:
             if section_key in bag:
                 yield cls.DOC205, (section_key,)  # Duplicate return section
 
+            if section_key in return_set and section_key != standard_return_key:
+                # Suggest using standard section key
+                yield cls.DOC013, (standard_return_key, section_key)
+
             if section_key in return_set:
                 bag.update(return_set)  # Mark all return section as used to avoid duplicates (:return: & :returns:)
             else:
@@ -468,6 +498,10 @@ class Violations:
                 # Raises after returns are considered misplaced
                 yield cls.DOC007, (section_key, first_return.section_key,)
 
+            if section_key in raises_set and section_key != standard_raise_key:
+                # Suggest using standard section key
+                yield cls.DOC013, (standard_raise_key, section_key)
+
     @classmethod
     def validate_variables(cls, parsed_docs, /):
         """Validate the variable sections of the parsed docstring."""
@@ -700,7 +734,7 @@ def parse_docs(node, filename, /):
         # Check for non-blank lines after the last section. (Only for type sections that cannot have a description)
         non_blank_end_lines = any(line.strip() for line in b_raw.splitlines()[1:])  # Non-empty lines
 
-    if docs:
+    if docs is not None:  # can be empty docstring
         summary = get_summary(docs)
         first = node.body[0]
         docs_ini_lineno, docs_end_lineno = (first.lineno, first.end_lineno)
@@ -853,7 +887,7 @@ def checker(node, violations, filename, /):
     """
     Explore the given AST node and yield each violation found.
 
-    :param ast.AST node: Root node to explore.
+    :param ast.Function node: Root node to explore.
     :param Violations violations: Violations instance with enabled/disabled rules.
     :param str filename: Filename to check.
 
@@ -862,18 +896,19 @@ def checker(node, violations, filename, /):
     """
 
     parsed_docs = parse_docs(node, filename)
-    lineno = parsed_docs.docs_ini_lineno
+    lineno_docs = parsed_docs.docs_ini_lineno
+    if lineno_docs is not None:  # Node has docstring
 
-    if parsed_docs.kind == NodeTypes.FUNCTION:
-        func_params_props = dict(get_params_props(node))
-        func_return_props = get_return_props(node, has_return_or_yield(node))
-        func_is_implemented = not is_not_implemented(node, rawdocs=parsed_docs.rawdocs)
-        parsed_func = ParsedFuncDef(func_params_props, func_return_props, func_is_implemented)
-    else:  # ClassDef or Module
-        parsed_func = None
+        if parsed_docs.kind == NodeTypes.FUNCTION:
+            func_params_props = dict(get_params_props(node))
+            func_return_props = get_return_props(node, has_return_or_yield(node))
+            func_is_implemented = not is_not_implemented(node, rawdocs=parsed_docs.rawdocs)
+            parsed_func = ParsedFuncDef(func_params_props, func_return_props, func_is_implemented)
+        else:  # ClassDef or Module
+            parsed_func = None
 
-    for (code, msg), ctx in violations.discover(parsed_docs, parsed_func):
-        yield (lineno, code, msg, ctx)
+        for (code, msg), ctx in violations.discover(parsed_docs, parsed_func):
+            yield (lineno_docs, code, msg, ctx)
 
 
 def walk_module(quiet, data, filename, /):
@@ -900,10 +935,10 @@ def walk_module(quiet, data, filename, /):
                 yield node
 
 
-def walk(paths, ignore_dirs, /):
+def walk(paths, ignore_dirs, quiet, /):
     suffix = ".py"
     for item in paths:
-        path = pathlib.Path(item)
+        path = pathlib.Path(item).resolve()
         if path.is_file():
             # The user requested this file.
             # return it even if it does not end with .py
@@ -917,7 +952,7 @@ def walk(paths, ignore_dirs, /):
                 for name in files:
                     if name.endswith(suffix):
                         yield pathlib.Path(os.path.join(root, name))
-        else:
+        elif not quiet:  # If False, print warnings to stderr.
             logging.warning("Unknown file: %s", path)
 
 
@@ -960,7 +995,7 @@ def get_config_start_dir(paths, /):
     return os.path.commonpath(parents)
 
 
-def load_config(config_file, check_files, /):
+def load_config(config_file, check_files, quiet, /):
     """
     Load configuration from 'pyproject.toml' if available.
 
@@ -969,15 +1004,18 @@ def load_config(config_file, check_files, /):
 
     :param str | None config_file: Path to 'pyproject.toml' file.
     :param list[str] check_files: List of files/directories to check.
+    :param bool quiet: If False, print warnings to stderr.
     :rtype: dict
     """
 
     config = dict()
 
-    if not tomllib:
+    if not tomllib and not quiet:
         msg = "tomllib not available; config files cannot be loaded. Please use Python 3.11+ to enable this feature."
         logging.warning(msg)
         return config
+    elif not tomllib:
+        return config
 
     if config_file:
         paths = (pathlib.Path(config_file),)
@@ -1076,14 +1114,14 @@ def main():
         dump_version()
         return 0
 
-    config = dict() if args.isolated else load_config(args.config, args.files)
+    config = dict() if args.isolated else load_config(args.config, args.files, args.quiet)
     # CLI Arguments have precedence over config file settings
     enable = args.enable or config.get("enable", [])
     disable = args.disable or config.get("disable", [])
     ignore = args.ignore or config.get("ignore", default_ignore_dirs)
 
     violations = Violations(enable=enable, disable=disable)
-    for path in walk(args.files, ignore):
+    for path in walk(args.files, ignore, args.quiet):
         dump_file(violations, args.quiet, path)
 
     if args.statistics and violations.stats:
