@@ -368,7 +368,7 @@ def foo(a):
 
 
 @pytest.mark.parametrize("docs", [
-    "A multi-line\ndocstring",
+    "A multi-line\n\ndocstring",
     "A one-line title\n\n:param str a:",
     "A one-line title\n\n:meta deprecated: foo",
 ])
@@ -384,8 +384,8 @@ def foo(a):
 
 
 @pytest.mark.parametrize("docs", [
-    '""""\nTitle."""',  # four quotes at the start
-    '"""" \nTitle."""',  # four quotes at the start with space
+    '""""\n\nTitle."""',  # four quotes at the start
+    '"""" \n\nTitle."""',  # four quotes at the start with space
 ])
 def test_DOC009(violations, docs):
     content = f'''
@@ -402,8 +402,8 @@ def foo():
 
 
 @pytest.mark.parametrize("docs", [
-    '""""Title."""',  # four quotes at the start
-    '"""" foo\nTitle."""',  # four quotes at the start with space because exists more words
+    '""""Title."""',  # four quotes at the start with no space because no more words
+    '"""" foo var."""',  # four quotes at the start with space because exists more words
 ])
 def test_DOC009_no_raise(violations, docs):
     content = f'''
@@ -654,6 +654,60 @@ def foo(a):
     assert result == expected
 
 
+def test_DOC013(violations):
+    content = '''
+def foo(a):
+    """Title.
+
+    :parameter str a: description
+    :raise ValueError: description
+    :returns: description
+    """
+    pass
+'''
+
+    expected = (
+        (3, 'DOC013', 'Use the common section key ({!r}) instead of ({!r})', ('param', 'parameter')),
+        (3, 'DOC013', 'Use the common section key ({!r}) instead of ({!r})', ('return', 'returns')),
+        (3, 'DOC013', 'Use the common section key ({!r}) instead of ({!r})', ('raises', 'raise')),
+    )
+
+    result = tuple(chequer(content, violations))
+    assert result == expected
+
+
+def test_DOC014(violations):
+    content = '''
+def foo(a):
+    """
+    Summary line.
+    Extended description of function.
+    """
+    pass
+'''
+
+    expected = ((3, 'DOC014', 'Summary must fit on a single line and is separated from the rest by a blank line.', ()),)
+
+    result = tuple(chequer(content, violations))
+    assert result == expected
+
+
+def test_DOC014_no_raise(violations):
+    content = '''
+def foo(a):
+    """
+    Summary line.
+
+    Extended description of function.
+    """
+    pass
+'''
+
+    expected = ()
+    result = tuple(chequer(content, violations))
+    assert result == expected
+
+
 @pytest.mark.parametrize("docs", ["", " ", "  ", "  \n"])
 def test_DOC012_ignore_if_blank_docstring(docs, violations):
     content = f'''
@@ -663,7 +717,7 @@ def foo(a):
 
     if "\n" in docs:
         # Raises DOC006 for trailing empty lines but not DOC012
-        expected = ((None, 'DOC006', 'Trailing empty lines', ()),)
+        expected = ((3, 'DOC006', 'Trailing empty lines', ()),)
     else:
         expected = ()
     result = tuple(chequer(content, violations))
@@ -930,6 +984,8 @@ def foo():
     expected = (
         ((3, "DOC205", "Duplicated return section ({!r})", (key,)),)
     )
+    if key == "returns":
+        expected += ((3, "DOC013", "Use the common section key ({!r}) instead of ({!r})", ("return", key,)),)
     result = tuple(chequer(content, violations))
     assert result == expected
 
@@ -940,7 +996,7 @@ def foo():
     """
     Title.
 
-    :raise except: description
+    :raises except: description
     """
 
     pass
